Gemeinde Adressverwaltung GUI: Elementverzeichnis

Gemeinde Adressverwaltung GUI

Gemeinde.dialogGemeindeAuswahl Elementverzeichnis

Vollständige Aufstellung aller Elemente für Gemeinde.dialogGemeindeAuswahl einschließlich aller geerbten Elemente.

__init__(self, parent, auswahl=[]) (Definiert in Gemeinde.dialogGemeindeAuswahl) | Gemeinde.dialogGemeindeAuswahl |
btnGo (Definiert in Gemeinde.dialogGemeindeAuswahl) | Gemeinde.dialogGemeindeAuswahl |
btnQuit (Definiert in Gemeinde.dialogGemeindeAuswahl) | Gemeinde.dialogGemeindeAuswahl |
frmButtons (Definiert in Gemeinde.dialogGemeindeAuswahl) | Gemeinde.dialogGemeindeAuswahl |
frmChoices (Definiert in Gemeinde.dialogGemeindeAuswahl) | Gemeinde.dialogGemeindeAuswahl |
handleOK(self) (Definiert in Gemeinde.dialogGemeindeAuswahl) | Gemeinde.dialogGemeindeAuswahl |
lblTitel (Definiert in Gemeinde.dialogGemeindeAuswahl) | Gemeinde.dialogGemeindeAuswahl |
parent (Definiert in Gemeinde.dialogGemeindeAuswahl) | Gemeinde.dialogGemeindeAuswahl |